@@ -71,19 +71,13 @@ set_abs_path
 cd "$CDIR"
 set_svn_local
 check_local
+check_translations
 svn_cp_to_tag
+update_pot
 #tag="1.0.2rc7Beta"
 #turl="$BURL/tags/$tag"
 #CODIR="$ASVN/test.$tag"
-test_tag_co
-make_tarball
-test_tarball
-build_deb
-echo "output in $CODIR"
-show_links
-exit 0
-
-
-	 
-
+rel_deb
+remote_i386
+copy_files_to_sourceforge
 
