@@ -199,10 +199,7 @@ is_hyper (const gchar *string)
  * 
  * Returns: %TRUE on success.
  */
-gboolean
-egg_accelerator_parse_virtual (const gchar            *accelerator,
-                               guint                  *accelerator_key,
-                               EggVirtualModifierType *accelerator_mods)
+gboolean egg_accelerator_parse_virtual (const gchar *accelerator, guint *accelerator_key, EggVirtualModifierType *accelerator_mods)
 {
   guint keyval;
   GdkModifierType mods;
@@ -221,106 +218,78 @@ egg_accelerator_parse_virtual (const gchar            *accelerator,
   keyval = 0;
   mods = 0;
   len = strlen (accelerator);
-  while (len)
-    {
-      if (*accelerator == '<')
-	{
-	  if (len >= 9 && is_release (accelerator))
-	    {
+  while (len)    {
+    if (*accelerator == '<')	{
+	  	if (len >= 9 && is_release (accelerator))	    {
 	      accelerator += 9;
 	      len -= 9;
 	      mods |= EGG_VIRTUAL_RELEASE_MASK;
-	    }
-	  else if (len >= 9 && is_control (accelerator))
-	    {
+	    } else if (len >= 9 && is_control (accelerator))  {
 	      accelerator += 9;
 	      len -= 9;
 	      mods |= EGG_VIRTUAL_CONTROL_MASK;
-	    }
-	  else if (len >= 7 && is_shift (accelerator))
-	    {
+	    } else if (len >= 7 && is_shift (accelerator))  {
 	      accelerator += 7;
 	      len -= 7;
 	      mods |= EGG_VIRTUAL_SHIFT_MASK;
-	    }
-	  else if (len >= 6 && is_shft (accelerator))
-	    {
+	    } else if (len >= 6 && is_shft (accelerator)) {
 	      accelerator += 6;
 	      len -= 6;
 	      mods |= EGG_VIRTUAL_SHIFT_MASK;
-	    }
-	  else if (len >= 6 && is_ctrl (accelerator))
-	    {
+	    } else if (len >= 6 && is_ctrl (accelerator)) {
 	      accelerator += 6;
 	      len -= 6;
 	      mods |= EGG_VIRTUAL_CONTROL_MASK;
-	    }
-	  else if (len >= 6 && is_modx (accelerator))
-	    {
+	    } else if (len >= 6 && is_modx (accelerator))  {
 	      static const guint mod_vals[] = {
-		EGG_VIRTUAL_ALT_MASK, EGG_VIRTUAL_MOD2_MASK, EGG_VIRTUAL_MOD3_MASK,
-		EGG_VIRTUAL_MOD4_MASK, EGG_VIRTUAL_MOD5_MASK
+				EGG_VIRTUAL_ALT_MASK, EGG_VIRTUAL_MOD2_MASK, EGG_VIRTUAL_MOD3_MASK,
+				EGG_VIRTUAL_MOD4_MASK, EGG_VIRTUAL_MOD5_MASK
 	      };
 
 	      len -= 6;
 	      accelerator += 4;
 	      mods |= mod_vals[*accelerator - '1'];
 	      accelerator += 2;
-	    }
-	  else if (len >= 5 && is_ctl (accelerator))
-	    {
+	    } else if (len >= 5 && is_ctl (accelerator)) {
 	      accelerator += 5;
 	      len -= 5;
 	      mods |= EGG_VIRTUAL_CONTROL_MASK;
-	    }
-	  else if (len >= 5 && is_alt (accelerator))
-	    {
+	    } else if (len >= 5 && is_alt (accelerator)) {
 	      accelerator += 5;
 	      len -= 5;
 	      mods |= EGG_VIRTUAL_ALT_MASK;
-	    }
-          else if (len >= 6 && is_meta (accelerator))
-	    {
+	    } else if (len >= 6 && is_meta (accelerator)) {
 	      accelerator += 6;
 	      len -= 6;
 	      mods |= EGG_VIRTUAL_META_MASK;
-	    }
-          else if (len >= 7 && is_hyper (accelerator))
-	    {
+	    } else if (len >= 7 && is_hyper (accelerator)) {
 	      accelerator += 7;
 	      len -= 7;
 	      mods |= EGG_VIRTUAL_HYPER_MASK;
-	    }
-          else if (len >= 7 && is_super (accelerator))
-	    {
+	    } else if (len >= 7 && is_super (accelerator)) {
 	      accelerator += 7;
 	      len -= 7;
 	      mods |= EGG_VIRTUAL_SUPER_MASK;
-	    }
-	  else
-	    {
+	    } else {
 	      gchar last_ch;
 	      
 	      last_ch = *accelerator;
-	      while (last_ch && last_ch != '>')
-		{
-		  last_ch = *accelerator;
-		  accelerator += 1;
-		  len -= 1;
+	      while (last_ch && last_ch != '>')	{
+		  		last_ch = *accelerator;
+		  		accelerator += 1;
+		  		len -= 1;
+				}
+			}
+		} else { /**accelerator != '<'  */
+      keyval = gdk_keyval_from_name (accelerator);
+          
+      if (keyval == 0)
+      	bad_keyval = TRUE;
+          
+      accelerator += len;
+      len -= len;              
 		}
-	    }
-	}
-      else
-	{
-          keyval = gdk_keyval_from_name (accelerator);
-          
-          if (keyval == 0)
-            bad_keyval = TRUE;
-          
-          accelerator += len;
-          len -= len;              
-	}
-    }
+  }
   
   if (accelerator_key)
     *accelerator_key = gdk_keyval_to_lower (keyval);
@@ -344,9 +313,7 @@ egg_accelerator_parse_virtual (const gchar            *accelerator,
  *
  * The caller of this function must free the returned string.
  */
-gchar*
-egg_virtual_accelerator_name (guint                  accelerator_key,
-                              EggVirtualModifierType accelerator_mods)
+gchar*egg_virtual_accelerator_name (guint accelerator_key, EggVirtualModifierType accelerator_mods)
 {
   static const gchar text_release[] = "<Release>";
   static const gchar text_shift[] = "<Shift>";
@@ -459,10 +426,7 @@ egg_virtual_accelerator_name (guint                  accelerator_key,
   return accelerator;
 }
 
-void
-egg_keymap_resolve_virtual_modifiers (GdkKeymap              *keymap,
-                                      EggVirtualModifierType  virtual_mods,
-                                      GdkModifierType        *concrete_mods)
+void egg_keymap_resolve_virtual_modifiers (GdkKeymap *keymap, EggVirtualModifierType  virtual_mods, GdkModifierType *concrete_mods)
 {
   GdkModifierType concrete;
   int i;
@@ -488,10 +452,7 @@ egg_keymap_resolve_virtual_modifiers (GdkKeymap              *keymap,
   *concrete_mods = concrete;
 }
 
-void
-egg_keymap_virtualize_modifiers (GdkKeymap              *keymap,
-                                 GdkModifierType         concrete_mods,
-                                 EggVirtualModifierType *virtual_mods)
+void egg_keymap_virtualize_modifiers (GdkKeymap *keymap, GdkModifierType concrete_mods, EggVirtualModifierType *virtual_mods)
 {
   GdkModifierType virtual;
   int i;
@@ -536,9 +497,7 @@ egg_keymap_virtualize_modifiers (GdkKeymap              *keymap,
   *virtual_mods = virtual;
 }
 
-static void
-reload_modmap (GdkKeymap *keymap,
-               EggModmap *modmap)
+static void reload_modmap (GdkKeymap *keymap, EggModmap *modmap)
 {
   XModifierKeymap *xmodmap;
   int map_size;
@@ -622,8 +581,7 @@ reload_modmap (GdkKeymap *keymap,
   XFreeModifiermap (xmodmap);
 }
 
-const EggModmap*
-egg_keymap_get_modmap (GdkKeymap *keymap)
+const EggModmap* egg_keymap_get_modmap (GdkKeymap *keymap)
 {
   EggModmap *modmap;
 
@@ -654,3 +612,4 @@ egg_keymap_get_modmap (GdkKeymap *keymap)
   
   return modmap;
 }
+
