@@ -48,14 +48,13 @@ not character.
 glong validate_utf8_text(gchar *text, glong len)
 {
 	const gchar *valid;
-	if(NULL == text)
+	if(NULL == text || len <= 0)
 		return 0;
 	text[len]=0;
 	if(FALSE == g_utf8_validate(text,-1,&valid)) {
-		g_fprintf(stderr,"Truncating invalid utf8 text entry: ");
 		len=valid-text;
 		text[len]=0;
-		g_fprintf(stderr,"'%s'\n",text);
+		g_fprintf(stderr,"Truncating invalid utf8 text entry: '%s'\n",text);
 	}
 	return len;
 }
@@ -76,7 +75,7 @@ void read_history_old ()
   if (history_file)   {
     /* Read the size of the first item */
     gint size=1;
-    
+    g_mutex_lock(hist_lock);
     /* Continue reading until size is 0 */
     while (size)   {
 			struct history_item *c;
@@ -103,6 +102,7 @@ void read_history_old ()
     /* Close file and reverse the history to normal */
     fclose(history_file);
     history_list = g_list_reverse(history_list);
+		g_mutex_unlock(hist_lock);
   }
 }
 
@@ -154,7 +154,6 @@ int check_magic(gchar *fmagic)
 			rtn= i+1;	
 			goto done;
 		}
-			
 	}
 	rtn=0;
 done:
@@ -170,6 +169,7 @@ Current scheme is to have the total zize of element followed by the type, then t
 ****************************************************************************/
 void read_history ()
 {
+	size_t x;
   /* Build file path */
   gchar* history_path = g_build_filename(g_get_user_data_dir(),HISTORY_FILE0,NULL); 
 	gchar *magic=g_malloc0(2+HISTORY_MAGIC_SIZE);
@@ -195,6 +195,7 @@ void read_history ()
 		}
 		if(dbg) g_printf("History Magic OK. Reading\n");
     /* Continue reading until size is 0 */
+		g_mutex_lock(hist_lock);
     while (size)   {
 			struct history_item *c;
 			if (fread(&size, 4, 1, history_file) != 1)
@@ -210,9 +211,9 @@ void read_history ()
 			if(c->len != end)
 				g_fprintf(stderr,"len check: invalid: ex %d got %d\n",end,c->len);
 			/* Read item and add ending character */
-			if (fread(&c->text,end,1,history_file) != 1){
+			if ((x =fread(&c->text,end,1,history_file)) != 1){
 				c->text[end] = 0;
-				g_fprintf(stderr,"history_read: Invalid text!\n'%s'\n",c->text);
+				g_fprintf(stderr,"history_read: Invalid text, code %ld!\n'%s'\n",(unsigned long)x,c->text);
 			}	else {
 				c->text[end] = 0;
 				c->len=validate_utf8_text(c->text,c->len);
@@ -228,6 +229,7 @@ done:
     /* Close file and reverse the history to normal */
     fclose(history_file);
     history_list = g_list_reverse(history_list);
+		g_mutex_unlock(hist_lock);
   }
 	if(dbg) g_printf("History read done\n");
 }
@@ -265,7 +267,7 @@ void save_history()
   gchar* history_path = g_build_filename(g_get_user_data_dir(), HISTORY_FILE0, NULL); 
   /* Open the file for writing */
   FILE* history_file = fopen(history_path, "wb");
-  g_free(history_path);
+  
   /* Check that it opened and begin write */
   if (history_file)  {
     GList* element;
@@ -273,6 +275,7 @@ void save_history()
 	  if( NULL == magic) return;
 		memcpy(magic,history_magics[HISTORY_VERSION-1],strlen(history_magics[HISTORY_VERSION-1]));	
 		fwrite(magic,HISTORY_MAGIC_SIZE,1,history_file);
+		g_mutex_lock(hist_lock);
     /* Write each element to a binary file */
     for (element = history_list; element != NULL; element = element->next) {
 		  struct history_item *c;
@@ -291,11 +294,15 @@ void save_history()
 			}
 			
     }
+		g_mutex_unlock(hist_lock);
     /* Write 0 to indicate end of file */
     gint end = 0;
     fwrite(&end, 4, 1, history_file);
     fclose(history_file);
-  }
+  }else{
+		g_fprintf(stderr,"Unable to open history file for save '%s'\n",history_path);
+	}
+	g_free(history_path);
 }
 
 /***************************************************************************/
@@ -307,7 +314,7 @@ struct history_item *new_clip_item(gint type, guint32 len, void *data)
 {
 	struct history_item *c;
 	if(NULL == (c=g_malloc0(sizeof(struct history_item)+len))){
-		printf("Hit NULL for malloc of history_item!\n");
+		g_fprintf(stderr,"Hit NULL for malloc of history_item!\n");
 		return NULL;
 	}
 		
@@ -353,7 +360,7 @@ gint is_duplicate(gchar* item, int mode, gint *flags)
 \n\b Arguments:
 \n\b Returns:
 ****************************************************************************/
-void append_item(gchar* item, int checkdup)
+void append_item(gchar* item, int checkdup, gint iflags, gint itype)
 {
 	gint flags=0,node=-1;
 	GList *element=NULL;
@@ -380,7 +387,9 @@ void append_item(gchar* item, int checkdup)
 		if(node > -1 && (checkdup & HIST_KEEP_FLAGS) ){
 			c->flags=flags;
 			/*g_printf("Restoring 0x%02X '%s'\n",c->flags,c->text);  */
-		}		
+		}	else
+			c->flags=iflags;
+		c->type=itype;
 	}
 	
 
@@ -388,9 +397,9 @@ void append_item(gchar* item, int checkdup)
 	/*g_printf("Append '%s'\n",item); */
    /* Prepend new item */
   history_list = g_list_prepend(history_list, NULL ==element?c:element->data);
+	g_mutex_unlock(hist_lock);
   /* Shorten history if necessary */
   truncate_history();
-	g_mutex_unlock(hist_lock);
 }
 
 /***************************************************************************/
@@ -403,6 +412,7 @@ void delete_duplicate(gchar* item)
   GList* element;
 	int p=get_pref_int32("persistent_history");
   /* Go through each element compare each */
+	g_mutex_lock(hist_lock);
   for (element = history_list; element != NULL; element = element->next) {
 	  struct history_item *c;
 		c=(struct history_item *)element->data;
@@ -415,11 +425,13 @@ void delete_duplicate(gchar* item)
 	    }
 		}
   }
+	g_mutex_unlock(hist_lock);
 }
 
 /***************************************************************************/
 /**  Truncates history to history_limit items, while preserving persistent
     data, if specified by the user. FIXME: This may not shorten the history 
+    
 \n\b Arguments:
 \n\b Returns:
 ****************************************************************************/
@@ -427,6 +439,7 @@ void truncate_history()
 {
   int p=get_pref_int32("persistent_history");
   if (history_list)  {
+		g_mutex_lock(hist_lock);
 		guint ll=g_list_length(history_list);
 		guint lim=get_pref_int32("history_limit");
 		if(ll > lim){ /* Shorten history if necessary */
@@ -440,7 +453,7 @@ void truncate_history()
 				}
 	    }	
 		}
-		
+		g_mutex_unlock(hist_lock);
     /* Save changes */
     if (get_pref_int32("save_history"))
       save_history();
@@ -473,7 +486,7 @@ gpointer get_last_item()
 ****************************************************************************/
 void clear_history( void )
 {
-	
+	g_mutex_lock(hist_lock);
 	if( !get_pref_int32("persistent_history")){
 		g_list_free(history_list);
 		history_list = NULL;
@@ -486,6 +499,7 @@ void clear_history( void )
 				history_list=g_list_remove(history_list,c);
 		}		
 	}
+	g_mutex_unlock(hist_lock);
   if (get_pref_int32("save_history"))
   	save_history();
 }
@@ -501,6 +515,7 @@ int save_history_as_text(gchar *path)
   if (fp)  {
 		gint i;
     GList* element;
+		g_mutex_lock(hist_lock);
     /* Write each element to  file */
     for (i=0,element = history_list; element != NULL; element = element->next) {
 		  struct history_item *c;
@@ -511,10 +526,12 @@ int save_history_as_text(gchar *path)
 				fprintf(fp,"NHIST_%04d %s\n",i,c->text);
 			++i;
     }
+		g_mutex_unlock(hist_lock);
     fclose(fp);
   }
 	
 	g_printf("histpath='%s'\n",path);
+	return 0;
 }
 /***************************************************************************/
 /** Dialog to save the history file.
