@@ -18,12 +18,14 @@
 #ifndef _PARCELLITE_H_
 #define _PARCELLITE_H_ 1
 #include <glib.h>
+#include <glib/gprintf.h>
 #include <gtk/gtk.h>
 #include <string.h>
 #include <unistd.h>
 #ifdef HAVE_APPINDICATOR
 #include <libappindicator/app-indicator.h>
 #endif
+#include <stdlib.h>
 #define PARCELLITE_PROG_NAME "parcellite"
 #define PARCELLITE_ICON PARCELLITE_PROG_NAME
 /*uncomment the next line to debug the clipboard updates
@@ -31,6 +33,21 @@
 must have debug_update enabled in prefs when started. 
 */
 /*#define DEBUG_UPDATE   */
+/* Uncomment the next line to print a debug trace. */
+/*#define DEBUG      */
+
+#ifdef DEBUG
+#  define TRACE(x) x
+#else
+#  define TRACE(x) do {} while (FALSE);
+#endif
+
+#ifdef DEBUG_UPDATE
+static int debug_update=0; /**disable/enable DTRACE  */
+#  define DTRACE(x) if (debug_update) x
+#else
+#  define DTRACE(x) do {} while (FALSE);
+#endif
 #include "daemon.h"
 #include "utils.h"
 #include "preferences.h"
