@@ -17,6 +17,10 @@
  */
 
 #include "parcellite.h"
+#include <sys/wait.h>
+
+void setup_icon( void ); /**in main.c  */
+
 #define MAX_HISTORY 1000
 
 #define INIT_HISTORY_KEY      NULL
@@ -62,20 +66,25 @@
 #define PREF_SEC_ACT	5
 #define PREF_SEC_XMISC 6
 
+#define RC_VERSION_NAME "RCVersion"
+#define RC_VERSION      1
+
 struct myadj {
 	gdouble lower;
 	gdouble upper;
 	gdouble step;
 	gdouble page;
 };
-
-struct myadj align_hist_xy={1,0,10,100};
-struct myadj align_data_lim={0,1000,1,10};
+static char *icon_name="parcellite";
+struct myadj align_hist_x={1,100,1,10};
+struct myadj align_hist_y={1,100,1,10};
+struct myadj align_data_lim={0,1000000,1,10};
 struct myadj align_hist_lim={5, MAX_HISTORY, 1, 10};
 struct myadj align_line_lim={5, DEF_ITEM_LENGTH_MAX, 1, 5};
 struct pref_item {
 	gchar *name;		/**name/id to find pref  */
 	gint32 val;			/**int val  */
+	float fval;
 	gchar *cval;	 /**char val  */
 	GtkWidget *w;	 /**widget in menu  */
 	gint type;		/**PREF_TYPE_  */
@@ -90,7 +99,14 @@ static struct pref_item dummy[2];
 static void check_toggled(GtkToggleButton *togglebutton, gpointer user_data);
 static void search_toggled(GtkToggleButton *b, gpointer user);
 static gint dbg=0;
-
+static int tool_bitfield=0;
+static int tool_bitfield_check=0;
+struct pref2int *pref2int_mapper=NULL;
+struct tool_flag tool_flags[]={
+	{.flag=TOOL_XDOTOOL,.name="xdotool"},
+	{.flag=0,.name=NULL },
+	/*{.flag=,.name= }, */
+};
 /**hot key list, mainly for easy sanity checks.  */
 struct keys keylist[]={
 	{.name="menu_key",.keyval=DEF_MENU_KEY,.keyfunc=(void *)menu_hotkey},
@@ -112,12 +128,13 @@ struct pref_item myprefs[]={
   {.adj=NULL,.cval=NULL,.sig=NULL,.sfunc=NULL,.sec=PREF_SEC_HIST,.name=NULL,.type=PREF_TYPE_FRAME,.desc="<b>History</b>",.tip=NULL,.val=0},
   {.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="save_history",.type=PREF_TYPE_TOGGLE,.desc="Save history",.tip="Save history to a file.",.val=DEF_SAVE_HISTORY},
   {.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_pos",.type=PREF_TYPE_TOGGLE|PREF_TYPE_SINGLE_LINE,.desc="Position history",.tip="If checked, use X, Y to position the history list",.val=0},
-  {.adj=&align_hist_xy,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_x",.type=PREF_TYPE_SPIN|PREF_TYPE_SINGLE_LINE,.desc="<b>X</b>",.tip=NULL,.val=1},
-  {.adj=&align_hist_xy,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_y",.type=PREF_TYPE_SPIN|PREF_TYPE_SINGLE_LINE,.desc="<b>Y</b>",.tip="Position in pixels from the top of the screen",.val=1},
+  {.adj=&align_hist_x,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_x",.type=PREF_TYPE_SPIN|PREF_TYPE_SINGLE_LINE,.desc="<b>X</b>",.tip=NULL,.val=1},
+  {.adj=&align_hist_y,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_y",.type=PREF_TYPE_SPIN|PREF_TYPE_SINGLE_LINE,.desc="<b>Y</b>",.tip="Position in pixels from the top of the screen",.val=1},
 	{.adj=&align_hist_lim,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="history_limit",.type=PREF_TYPE_SPIN,.desc="Items in history",.tip="Maximum number of clipboard entries to keep",.val=DEF_HISTORY_LIMIT},
-  {.adj=&align_data_lim,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="data_size",.type=PREF_TYPE_SPIN,.desc="Max Data Size(MB)",.tip="Maximum data size of entire history list",.val=0},
+  {.adj=&align_data_lim,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="data_size",.type=PREF_TYPE_SPIN,.desc="Max Data Size(KB)",.tip="Maximum data size of entire history list",.val=0},
+  {.adj=&align_hist_lim,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="item_size",.type=PREF_TYPE_SPIN,.desc="Max Item Size(KB)",.tip="Maximum data size of one item",.val=0},
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="nop",.type=PREF_TYPE_SPACER,.desc=" ",.tip=NULL},
-	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="automatic_paste",.type=PREF_TYPE_TOGGLE|PREF_TYPE_SINGLE_LINE,.desc="Auto Paste",.tip="If checked, will use xdotool to paste wherever the mouse is.",.val=0},
+	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="automatic_paste",.type=PREF_TYPE_TOGGLE|PREF_TYPE_SINGLE_LINE,.desc="Auto Paste",.tip="If checked, will use xdotool to paste wherever the mouse is.\nNOTE! Package xdotool MUST BE INSTALLED for this to work.",.val=0},
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="auto_key",.type=PREF_TYPE_TOGGLE|PREF_TYPE_SINGLE_LINE,.desc="Key",.tip="If checked, will use Ctrl-V paste.",.val=0},
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="auto_mouse",.type=PREF_TYPE_TOGGLE|PREF_TYPE_SINGLE_LINE,.desc="Mouse",.tip="If checked, will use middle mouse to paste.",.val=1},
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_HIST,.name="key_input",.type=PREF_TYPE_TOGGLE,.desc="Keyboard Input",.tip="If checked, will emit the history entry via the keyboard entry.",.val=0},
@@ -153,6 +170,7 @@ struct pref_item myprefs[]={
 /**miscellaneous that doesn't fit elswhew  */	
   {.adj=NULL,.cval=NULL,.sig=NULL,.sfunc=NULL,.sec=PREF_SEC_XMISC,.name=NULL,.type=PREF_TYPE_FRAME,.desc="<b>Miscellaneous</b>",.tip=NULL,.val=0},
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_XMISC,.name="multi_user",.type=PREF_TYPE_TOGGLE,.desc="Multiuser",.tip="If checked, enables checking multiple concurrent user logic. Use if several different users are logged in at the same time.",.val=TRUE},
+	{.adj=NULL,.cval=PARCELLITE_ICON,.sig=NULL,.sec=PREF_SEC_XMISC,.name="icon_name",.type=PREF_TYPE_ENTRY,.desc="Parcellite Icon Name",.tip="Name of Parcellite icon. If this is mis-typed, icon will not appear.",.val=TRUE},
 #ifdef	DEBUG_UPDATE
 	{.adj=NULL,.cval=NULL,.sig=NULL,.sec=PREF_SEC_XMISC,.name="debug_update",.type=PREF_TYPE_TOGGLE,.desc="DebugUpdate",.tip="If checked, enables debug prints on clipboard update logic. This only takes effect when enabled at start up, and may be disabled at compile time.",.val=FALSE},
 #endif
@@ -169,6 +187,45 @@ struct pref_item myprefs[]={
 GtkListStore* actions_list;
 GtkTreeSelection* actions_selection;
 
+/***************************************************************************/
+/** Set up which tools are available on the system.
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+static void check_for_tools_exit(GPid pid, gint status, gpointer data)
+{
+	int flag= GPOINTER_TO_INT(data);
+  g_spawn_close_pid(pid);
+	if( WIFEXITED(status) ){
+		if(0 ==WEXITSTATUS(status) )
+			tool_bitfield|=flag;
+		
+	}
+	tool_bitfield_check &= ~(flag);
+	g_fprintf(stderr,"Flag 0x%04x, status %d, EXIT %d STAT %d\n",flag,status,WIFEXITED(status),WEXITSTATUS(status) ); 
+		
+}
+/***************************************************************************/
+/** Check for installed tools and set flags accordingly.
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+void check_for_tools(void )
+{
+	GPid pid;
+  gchar **argv;
+	int i;
+	for (i=0; NULL != tool_flags[i].name; ++i){
+		gchar cmd[100];
+		tool_bitfield_check|=tool_flags[i].flag;
+		sprintf(cmd,"/bin/sh -c 'which %s'>/dev/null\n",tool_flags[i].name);
+		g_shell_parse_argv(cmd, NULL, &argv, NULL);
+		g_spawn_async(NULL, argv, NULL, G_SPAWN_DO_NOT_REAP_CHILD, NULL, NULL, &pid, NULL);
+		g_child_watch_add(pid, (GChildWatchFunc)check_for_tools_exit, GINT_TO_POINTER(tool_flags[i].flag));
+		g_strfreev(argv);
+	}
+}
+
 /***************************************************************************/
 /** .
 \n\b Arguments:
@@ -186,6 +243,24 @@ struct pref_item* get_pref(char *name)
 	return &dummy[0];
 }
 /***************************************************************************/
+/** Set an array that is updated every time the preferences are changed.
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+void pref_mapper (struct pref2int *m, int mode)
+{
+	int i;
+	if(PM_INIT == mode){
+		pref2int_mapper=m;
+		return;
+	}
+	for (i=0; pref2int_mapper[i].name != NULL && pref2int_mapper[i].val != NULL; ++i){
+		struct pref_item *p=get_pref(pref2int_mapper[i].name);
+		*pref2int_mapper[i].val=p->val;
+	}
+	
+}
+/***************************************************************************/
 /** .
 \n\b Arguments: pointer of widget
 \n\b Returns: Structure of item
@@ -226,12 +301,20 @@ int get_first_pref(int section)
 ****************************************************************************/
 int init_pref( void )
 {
+	GdkScreen *s;
+	gint sx,sy;
+	s=gdk_screen_get_default();
+	sx= gdk_screen_get_width(s);
+	sy= gdk_screen_get_height(s);
 	dummy[0].cval="dummy String";
 	dummy[0].w=NULL;
 	dummy[0].desc="Dummy desc";
 	dummy[0].tip="Dummy tip";
 	dummy[1].name=NULL;
 	dummy[1].sec=PREF_SEC_NONE;
+	align_hist_y.upper=sy-100;
+	align_hist_x.upper=sx-100;
+	return 0;
 }
 /***************************************************************************/
 /** set the wideget of item.
@@ -244,6 +327,7 @@ int set_pref_widget (char *name, GtkWidget *w)
 	if(NULL == p)
 		return -1;
 	p->w=w;
+	return 0;
 }
 /***************************************************************************/
 /** get the char * value of string.
@@ -283,6 +367,32 @@ gint32 get_pref_int32 (char *name)
 		return -1;
 	return p->val;
 }
+/***************************************************************************/
+/** Set the float value of name.
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+int set_pref_float(char *name, float fval)
+{
+	struct pref_item *p=get_pref(name);
+	if(NULL == p)
+		return -1;
+	p->fval=fval;
+	return 0;
+}
+
+/***************************************************************************/
+/** get the float value of name.
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+float get_pref_float (char *name)
+{
+	struct pref_item *p=get_pref(name);
+	if(NULL == p)
+		return -1;
+	return p->fval;
+}
 
 /***************************************************************************/
 /** set the char *value of string.
@@ -297,6 +407,7 @@ int set_pref_string (char *name, char *string)
 	if(p->cval != NULL)
 		g_free(p->cval);
 	p->cval=g_strdup(string);
+	return 0;
 }
 
 /***************************************************************************/
@@ -358,7 +469,10 @@ void set_key_entry(gchar *name, gchar *val)
 	int i;
 	for (i=0;NULL != keylist[i].name; ++i){
 		if(!g_strcmp0(keylist[i].name,name)){
-			keylist[i].keyval=val;
+		  if(NULL == val)
+		  	keylist[i].keyval="";
+			else
+				keylist[i].keyval=val;
 			return;
 		}
 	}
@@ -372,7 +486,6 @@ void set_key_entry(gchar *name, gchar *val)
 void set_keys_from_prefs( void )
 {
 	int i,l;
-	gchar *cval;
 	for (i=0;NULL != keylist[i].name; ++i){
 		/**NOTE: do not set up default keys here! User may WANT them null */
 			/** call egg_accelerator_parse_virtual to validate? */
@@ -399,15 +512,28 @@ void set_keys_from_prefs( void )
 /***************************************************************************/
 /** .
 \n\b Arguments:
+mode - if 0, do not display helper missing dialog.
 \n\b Returns:
 ****************************************************************************/
-void check_sanity(void)
+void check_sanity(int mode)
 {
 	gint32 x,y;
 	gchar *val;
-	postition_history(NULL,&x,&y,NULL, (gpointer)1);
-  if(get_pref_int32("history_x")>x) set_pref_int32("history_x",x);
-  if(get_pref_int32("history_y")>y) set_pref_int32("history_y",y);
+	check_for_tools(); /**update the list of tools parcellite needs.  */
+	while(tool_bitfield_check){
+		g_main_context_iteration(NULL, TRUE);
+		usleep(100000);
+	}
+	val=get_pref_string("icon_name");
+	if(NULL != val && strcmp(icon_name, val)){
+		setup_icon( );
+		icon_name=strdup(val);
+	}
+	x=get_pref_int32("history_x");
+	y=get_pref_int32("history_y");
+	postition_history(NULL,&x,&y,NULL, 0); /**have function limit x,y according to screen limits */
+  set_pref_int32("history_x",x);
+  set_pref_int32("history_y",y);
  	x=get_pref_int32("history_limit");
   if ((!x) || (x > MAX_HISTORY) || (x < 0))
     set_pref_int32("history_limit",DEF_HISTORY_LIMIT);
@@ -428,11 +554,17 @@ void check_sanity(void)
 	  set_pref_int32("persistent_on_top",0);
 	}
 	if(get_pref_int32("automatic_paste")){
-	
-		if(get_pref_int32("auto_key") && get_pref_int32("auto_mouse"))
-			set_pref_int32("auto_key",0);
-		if(!get_pref_int32("auto_key") && !get_pref_int32("auto_mouse"))
-			set_pref_int32("auto_mouse",1);
+		if(!(tool_bitfield&TOOL_XDOTOOL)){ 
+			g_fprintf(stderr,"tool_bitfield=0x%x\n",tool_bitfield);
+			set_pref_int32("automatic_paste",0);
+			if( mode )
+				show_gtk_dialog("xdotool is not installed\nParcellite's auto-paste will not function without xdotool.","xdotool Not Installed" ); 
+		} else{
+			if(get_pref_int32("auto_key") && get_pref_int32("auto_mouse"))
+				set_pref_int32("auto_key",0);
+			if(!get_pref_int32("auto_key") && !get_pref_int32("auto_mouse"))
+				set_pref_int32("auto_mouse",1);	
+		}
 	}
 }
 /* Apply the new preferences */
@@ -453,6 +585,7 @@ static void apply_preferences()
 				break;
 			case PREF_TYPE_SPIN:
 				myprefs[i].val=gtk_spin_button_get_value_as_int((GtkSpinButton*)myprefs[i].w);
+				myprefs[i].fval=(float)gtk_spin_button_get_value((GtkSpinButton*)myprefs[i].w);
 				break;
 			case PREF_TYPE_COMBO:
 				myprefs[i].val=gtk_combo_box_get_active((GtkComboBox*)myprefs[i].w) + 1;
@@ -466,11 +599,12 @@ static void apply_preferences()
 				break;
 		}
 	}
-  check_sanity();
+  check_sanity(1);
   /* Bind keys and apply the new history limit */
 	for (i=0;NULL != keylist[i].name; ++i)
 	  bind_itemkey(keylist[i].name,keylist[i].keyfunc);	
   truncate_history();
+	pref_mapper(NULL, PM_UPDATE);
 }
 
 
@@ -484,6 +618,7 @@ static void save_preferences()
 	int i;
   /* Create key */
   GKeyFile* rc_key = g_key_file_new();
+	g_key_file_set_integer(rc_key, "rc", RC_VERSION_NAME, RC_VERSION);
   if(0 == get_pref_int32("type_search"))
     set_pref_int32("case_search",0);
   /* Add values */
@@ -520,19 +655,21 @@ static void save_preferences()
 /***************************************************************************/
 /** Read the parcelliterc file.
 \n\b Arguments:
+mode - 0 to not display missing helper warnings 
 \n\b Returns:
 ****************************************************************************/
-void read_preferences()
+void read_preferences(int mode)
 {
 	gchar *c,*rc_file = g_build_filename(g_get_user_config_dir(), PREFERENCES_FILE, NULL);
   gint32 z;
-  GError *err;
+  GError *err=NULL;
 	struct pref_item *p;
 	init_pref();
   /* Create key */
   GKeyFile* rc_key = g_key_file_new();
   if (g_key_file_load_from_file(rc_key, rc_file, G_KEY_FILE_NONE, NULL)) {
 		int i;
+		i=g_key_file_get_integer(rc_key, "rc", RC_VERSION_NAME,&err); /**this begins in 1.1.8  */
 		/* Load values */
 		for (i=0;NULL != myprefs[i].desc; ++i){
 			if(NULL == myprefs[i].name)
@@ -573,7 +710,7 @@ void read_preferences()
 		}
       
     /* Check for errors and set default values if any */
-    check_sanity();
+    check_sanity(mode);
   }
   else  { /* Init default keys on error */
 	  int i;
@@ -581,6 +718,7 @@ void read_preferences()
 		for (i=0;NULL != keylist[i].name; ++i)
 			set_pref_string(keylist[i].name,def_keyvals[i]);
   }
+	pref_mapper(NULL, PM_UPDATE);
   g_key_file_free(rc_key);
   g_free(rc_file);
 }
@@ -855,7 +993,7 @@ int add_section(int sec, GtkWidget *parent)
 {
 	int i,rtn=0;
 	int single_st, single_is;
-	gint x,y,connect;
+	gint connect;
 	GtkWidget *hbox, *label, *child, *vbox, *alignment;
 	GtkWidget* packit;
 	vbox=parent;
@@ -970,8 +1108,6 @@ void show_preferences(gint tab)
   /* Declare some variables */
   GtkWidget *frame,*label,*alignment,*hbox, *vbox;
 	struct pref_item *p;
-  GtkObject *adjustment;
-  gint x,y;
   GtkTreeViewColumn *tree_column;
 	init_pref();
   
