@@ -42,11 +42,13 @@ try to allocate using other methods.
 gchar *p_strdup( const gchar *str )
 {
   gchar *n=NULL;
-  gint u8;
   size_t l,x;
   if(NULL == str)
     return NULL;
-	x=get_pref_int32("data_size")*1000000; 
+	x=get_pref_int32("item_size")*1000; 
+	l=get_pref_int32("data_size")*1000; 
+	if(l>0 && l<x) /**whichever is smaller, limit.  */
+		x=l;
   if(0 == x)
     return g_strdup(str);
 		/**use the following to test truncation  */
@@ -68,10 +70,11 @@ gchar *p_strdup( const gchar *str )
 }
 
 /* Creates program related directories if needed */
-void check_dirs()
+void check_dirs( void )
 {
   gchar* data_dir = g_build_path(G_DIR_SEPARATOR_S, g_get_user_data_dir(), DATA_DIR,  NULL);
   gchar* config_dir = g_build_path(G_DIR_SEPARATOR_S, g_get_user_config_dir(), CONFIG_DIR,  NULL);
+	gchar *rc_file;
 	
   /* Check if data directory exists */
   if (!g_file_test(data_dir, G_FILE_TEST_EXISTS))
@@ -87,8 +90,33 @@ void check_dirs()
     if (g_mkdir_with_parents(config_dir, 0755) != 0)
       g_warning(_("Couldn't create directory: %s\n"), config_dir);
   }
-  /* Cleanup */
-  g_free(data_dir);
+	/**now see if we need to setup any config files  */
+	rc_file = g_build_filename(g_get_user_config_dir(), PREFERENCES_FILE, NULL);
+	if(0 != access(rc_file,  R_OK)){/**doesn't exist */
+		const gchar * const *sysconfig=g_get_system_config_dirs();	/**NULL-terminated list of strings  */
+		const gchar * const *d;
+		gchar *sysrc;
+		for (d=sysconfig; NULL!= *d; ++d){
+			sysrc=g_build_filename(*d, PREFERENCES_FILE, NULL);
+			g_fprintf(stderr,"Looking in '%s'\n",sysrc);
+			if(0 == access(sysrc,  F_OK)){/**exists */
+				GError *e=NULL;
+				GFile *src=g_file_new_for_path(sysrc);
+				GFile *dst=g_file_new_for_path(rc_file);
+				g_fprintf(stderr,"Using parcelliterc from '%s', place in '%s'\n",sysrc,rc_file);
+				if(FALSE ==g_file_copy(src,dst,G_FILE_COPY_NONE,NULL,NULL,NULL,&e)){
+					g_fprintf(stderr,"Failed to copy. %s\n",e->message);
+				}
+				g_free(sysrc);
+				goto done;
+			}	
+			g_free(sysrc);
+		}
+	}	
+done:
+	/* Cleanup */
+	g_free(rc_file);
+	g_free(data_dir);
   g_free(config_dir);
 }
 
@@ -277,15 +305,15 @@ int get_value_from_env(pid_t pid, gchar *key, char **value)
 		g_fprintf(stderr,"Unable to allocate for environ file name.\n");
 		return rtn;
 	}
-	g_sprintf(envf,"/proc/%ld/environ",pid);
+	g_sprintf(envf,"/proc/%ld/environ",(long int)pid);
 	if(0 != access(envf,  R_OK)){/**doesn't exist, or not our process  */
-		g_fprintf(stderr,"Unable to open '%s' for PID %ld\n",envf,pid);
+		g_fprintf(stderr,"Unable to open '%s' for PID %ld\n",envf,(long int)pid);
 		goto error;
 	}
 	fp=g_file_new_for_path(envf);
 	/**this dumps a zero at end of file.  */
 	if(FALSE == g_file_load_contents(fp,NULL,&env,&elen,NULL,NULL)	){
-		g_fprintf(stderr,"Error finding '%s' for PID %ld\n",envf,pid);
+		g_fprintf(stderr,"Error finding '%s' for PID %ld\n",envf,(long int)pid);
 		goto error;
 	}
 	if(NULL == env){
@@ -300,7 +328,6 @@ int get_value_from_env(pid_t pid, gchar *key, char **value)
 		
 		if(NULL != f){
 			if(i==0 || f[-1] == 0){/**beginning terminators  */
-				gsize k;
 				i+=f-&env[i]; /**beginning of string  */
 				while(i<elen && 0!=env[i] && '=' !=env[i]) ++i;
 				if('=' == env[i] ){/**found, return key  */
@@ -426,7 +453,7 @@ done:
 ****************************************************************************/
 int is_current_xsession (pid_t pid)
 {
-	int i,x,rtn=1;
+	int i,x;
 	gchar *names[]={"XDG_SESSION_COOKIE","XDG_SEAT","DISPLAY",NULL};
 		
 	for (i=0;NULL != names[i]; ++i){
@@ -736,8 +763,8 @@ int read_fifo(struct p_fifo *f, int which)
 ****************************************************************************/
 int write_fifo(struct p_fifo *f, int which, char *buf, int len)
 {
-	int i, l,fd;
-	l=0;
+	int x,i, l,fd;
+	x=i=l=0;
 	switch(which){
 		case FIFO_MODE_PRI:
 			if(f->dbg) g_fprintf(stderr,"Using pri fifo for write\n");
@@ -754,10 +781,10 @@ int write_fifo(struct p_fifo *f, int which, char *buf, int len)
 	if(NULL ==f || fd <3 || NULL ==buf)
 		return -1;
 	if(f->dbg) g_fprintf(stderr,"writing '%s'\n",buf);
-	while(len){																							
-		i=write(fd,buf,len);
-		if(i>0)
-			len-=i;
+	while(len-i>0){	
+		x=write(fd,&buf[i],len-i);
+		if(x>0)
+			i+=x;
 		++l;
 		if(l>0x7FFE){
 			g_fprintf(stderr,"Maxloop hit\n");
@@ -765,7 +792,7 @@ int write_fifo(struct p_fifo *f, int which, char *buf, int len)
 		}
 			
 	}
-	if( -1 == i){
+	if( -1 == x){
 		if( EAGAIN != errno){
 			perror("write_fifo");
 			return -1;
@@ -775,8 +802,6 @@ int write_fifo(struct p_fifo *f, int which, char *buf, int len)
 }
 
 
-
-
 /***************************************************************************/
 /** Figure out who we are, then open the fifo accordingly.
 return the fifo file descriptor, or -1 on error
@@ -867,4 +892,22 @@ void close_fifos(struct p_fifo *f)
 }
 
 
+/***************************************************************************/
+/** .
+\n\b Arguments:
+\n\b Returns:
+****************************************************************************/
+void show_gtk_dialog(gchar *message, gchar *title)
+{
+GtkWidget *dialog;
+	if(NULL == message || NULL == title)
+		return;
+	dialog= gtk_message_dialog_new(NULL,GTK_DIALOG_DESTROY_WITH_PARENT,
+	            GTK_MESSAGE_WARNING,  GTK_BUTTONS_OK,
+	            message,NULL);
+	gtk_window_set_title(GTK_WINDOW(dialog), title ); 
+	gtk_widget_show_all(dialog);
+	gtk_dialog_run(GTK_DIALOG(dialog));
+	gtk_widget_destroy(dialog);	
+}
 
